summaryrefslogtreecommitdiff
path: root/nuttx/sched/pg_internal.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2010-08-15 16:50:25 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2010-08-15 16:50:25 +0000
commite29947db6aba1a4797b093b64548e40ad14d12b0 (patch)
treebf022bdca59370edf1dae8d42e3c4a86be392e74 /nuttx/sched/pg_internal.h
parentaa8fe0d6cf94a297fd0e7c8a6ab1ddb315fda57e (diff)
downloadpx4-nuttx-e29947db6aba1a4797b093b64548e40ad14d12b0.tar.gz
px4-nuttx-e29947db6aba1a4797b093b64548e40ad14d12b0.tar.bz2
px4-nuttx-e29947db6aba1a4797b093b64548e40ad14d12b0.zip
Add logic to drop the priority of the page fill task
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@2857 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/sched/pg_internal.h')
-rwxr-xr-xnuttx/sched/pg_internal.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/sched/pg_internal.h b/nuttx/sched/pg_internal.h
index 15f7bbb18..6ea35eed4 100755
--- a/nuttx/sched/pg_internal.h
+++ b/nuttx/sched/pg_internal.h
@@ -87,10 +87,10 @@
extern pid_t g_pgworker;
/* The page fill worker thread maintains a static variable called
* g_pendingfilltcb. If no fill is in progress, g_pendingfilltcb will be NULL.
* Otherwise, g_pendingfile will point to the TCB of the task which is
* receiving the fill that is in progess.
*
* NOTE: I think that this is the only state in which a TCB does not reside
* in some list. Here is it in limbo, outside of the normally queuing while
@@ -98,7 +98,7 @@ extern pid_t g_pgworker;
* TSTATE_TASK_INVALID.
*/
-extern FAR _TCB *g_pendingfilltcb;
+extern FAR _TCB *g_pftcb;
/****************************************************************************
* Public Function Prototypes
@@ -87,10 +87,10 @@
extern pid_t g_pgworker;
-/* The page fill worker thread maintains a static variable called
- * g_pendingfilltcb. If no fill is in progress, g_pendingfilltcb will be NULL.
- * Otherwise, g_pendingfile will point to the TCB of the task which is
- * receiving the fill that is in progess.
+/* The page fill worker thread maintains a static variable called g_pftcb.
+ * If no page fill is in progress, g_pftcb will be NULL. Otherwise, g_pftcb
+ * will point to the TCB of the task which is receiving the fill that is
+ * in progess.
*
* NOTE: I think that this is the only state in which a TCB does not reside